@@ -8,7 +8,19 @@ use std::path::PathBuf;
 fn main() {
     // Tell cargo to tell rustc to link the system bzip2
     // shared library.
+    println!("cargo:rustc-link-lib=r_io");
+    println!("cargo:rustc-link-lib=r_asm");
+    println!("cargo:rustc-link-lib=r_anal");
+    println!("cargo:rustc-link-lib=r_search");
+    println!("cargo:rustc-link-lib=r_util");
+    println!("cargo:rustc-link-lib=r_reg");
+    println!("cargo:rustc-link-lib=r_debug");
+    println!("cargo:rustc-link-lib=r_lang");
+    println!("cargo:rustc-link-lib=r_bin");
+    println!("cargo:rustc-link-lib=r_syscall");
     println!("cargo:rustc-link-lib=r_core");
+    println!("cargo:rustc-link-lib=r_socket");
+    println!("cargo:rustc-link-lib=r_fs");
     println!("cargo:rustc-link-lib=r_cons");
 
     // Tell cargo to invalidate the built crate whenever the wrapper changes
